@@ -18,6 +18,7 @@ import sys
 
 from KeyMappings import *
 from ZeeButton import ZeeButton
+from Zeemote import ZeeDiscover
 
 # If a user config directoryis present try to load mappings
 # from there.
@@ -48,11 +49,13 @@ class ZeecontrolGUI(hildon.Program):
     vbox.pack_start(zeeButtonBox)
     zeeButtonBox.show()
 
-    self.zeeButton1 = ZeeButton(self, zeeButtonBox, 1)
-    self.zeeButton2 = ZeeButton(self, zeeButtonBox, 2)
-    self.zeeButton3 = ZeeButton(self, zeeButtonBox, 3)
-    self.zeeButton4 = ZeeButton(self, zeeButtonBox, 4)
-    self.selectedZeeButton = self.zeeButton1
+    zeeDiscover = ZeeDiscover()
+    deviceCount = zeeDiscover.getZeemoteCount()
+    print "Found %d Zeemote(s)." % deviceCount
+    for i in range (1, deviceCount+1):
+      zeeButton = ZeeButton(self, zeeButtonBox, i)
+      if i == 1:
+        self.selectedZeeButton = zeeButton
 
     buttonBox1 = gtk.HBox(False, 0)        
     vbox.pack_start(buttonBox1)
@@ -111,7 +114,7 @@ class ZeecontrolGUI(hildon.Program):
     self.selectedZeeButton.setMapping(newMapping, newAltMapping)
 
   def setSelectedZeeButton(self, zeeButton):
-    self.selectedZeeButton(zeeButton)
+    self.selectedZeeButton = zeeButton
 
   def signalUser(self, usertext):
     self.label.set_text(usertext)
