@@ -68,7 +68,10 @@ class ZeemoteDeviceStruct(Structure):
 
 class ZeemoteScanResultStruct(Structure):
   _fields_ = [("number_of_devices", c_int),
-              ("device", ZeemoteDeviceStruct)]
+              ("device", ZeemoteDeviceStruct * 1)]
+
+getScanResults = zeemoteConf.zeemote_get_scan_results_from_gconf
+getScanResults.restype = POINTER(ZeemoteScanResultStruct)
 
 class Zeemote():
   def __init__(self, pointer):
@@ -94,18 +97,31 @@ class ZeemoteState():
   def getButtonMask(self):
     return self.s.buttons
 
+def addrToHex(array):
+  length = len(array)
+  ret = '00:'*(6-length)
+  ret = ret + ''.join( [ "%02X:" % ord(x) for x in array[::-1] ] )
+  return ret[0:17]
+
 class ZeeDiscover():
   def __init__(self):
     gobj.g_type_init()
 
   def getZeemote(self, id):
-    getScanResults = zeemoteConf.zeemote_get_scan_results_from_gconf
-    getScanResults.restype = POINTER(ZeemoteScanResultStruct)
+    devCount = self.getZeemoteCount()
+    if devCount > 1:
+      ZeemoteScanResultStruct._fields_ = [("number_of_devices", c_int),
+              ("device", ZeemoteDeviceStruct * devCount)]
+      
     result = getScanResults()
 
+    confDev = result[0].device[id]
+    addr = confDev.bdaddr
+    print "Connecting to Zeemote with address %s." % addrToHex(addr.b)
+
     connect = zeemote.zeemote_connect
     connect.restype = POINTER(ZeemoteStruct)
-    dev = connect(byref(result[id].device.bdaddr))
+    dev = connect(byref(addr))
  
     state = getState(dev)
     while state[0].state != 3:
@@ -113,7 +129,12 @@ class ZeeDiscover():
       state = getState(dev)
       if state[0].state == 2:
         zeemote.zeemote_disconnect(dev)
-        dev = connect(byref(result[0].device.bdaddr))
+        dev = connect(byref(addr))
 
     return Zeemote(dev)
 
+  def getZeemoteCount(self):
+    result = getScanResults()
+    return result[0].number_of_devices
+
+
